@@ -145,3 +145,36 @@ def trx_decrypt(aes_key: bytes, encrypted_trx: dict):
         "TimeStamp": encrypted_trx.get("TimeStamp"),
     }
     return decrpyted_trx
+
+
+# copy and update from https://github.com/zhangwm404/quorum-lightnode-py/blob/main/lightnode/content.py
+def get_content_param(
+    aes_key: bytes,
+    group_id: str,
+    start_trx: str = None,
+    num: int = 20,
+    reverse: bool = False,
+    include_start_trx: bool = False,
+    senders=None,
+) -> dict[str, str]:
+    params = {
+        "group_id": group_id,
+        "reverse": "true" if reverse is True else "false",
+        "num": num,
+        "include_start_trx": "true" if include_start_trx is True else "false",
+        "senders": senders or [],
+    }
+    if start_trx:
+        params["start_trx"] = start_trx
+
+    get_group_ctn_item = {
+        "Req": params,
+    }
+
+    get_group_ctn_item_str = json.dumps(get_group_ctn_item)
+    encrypted = aes_encrypt(aes_key, get_group_ctn_item_str.encode())
+    send_param = {
+        "Req": base64.b64encode(encrypted).decode(),
+    }
+
+    return send_param
